@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# (c) Copyright IBM Corp. 2010, 2020. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2023. All Rights Reserved.
 
 """ Implementation of `resilient-sdk codegen` """
 
@@ -9,13 +9,14 @@ import logging
 import os
 import re
 import shutil
+from datetime import datetime
 
 from resilient import ensure_unicode
 from resilient_sdk.cmds.base_cmd import BaseCmd
 from resilient_sdk.util import constants
 from resilient_sdk.util import package_file_helpers as package_helpers
 from resilient_sdk.util import sdk_helpers
-from resilient_sdk.util.resilient_objects import ResilientObjMap
+from resilient_sdk.util.resilient_objects import ResilientObjMap, MD_FILE_PROPERTIES
 from resilient_sdk.util.sdk_exception import SDKException
 from resilient_sdk.util.sdk_genson_overwrites import main_genson_builder_overwrites, CustomSchemaBuilder
 
@@ -30,13 +31,14 @@ class CmdCodegen(BaseCmd):
     CMD_HELP = "Generates boilerplate code used to begin developing an app."
     CMD_USAGE = """
     $ resilient-sdk codegen -p <name_of_package> -m 'fn_custom_md' --rule 'Rule One' 'Rule Two' -i 'custom incident type'
+    $ resilient-sdk codegen -p <name_of_package> -m 'fn_custom_md' --rule 'Rule One' 'Rule Two' --settings <path_to_custom_sdk_settings_file>
     $ resilient-sdk codegen -p <name_of_package> -m 'fn_custom_md' -c '/usr/custom_app.config'
     $ resilient-sdk codegen -p <path_current_package> --reload --workflow 'new_wf_to_add'
     $ resilient-sdk codegen -p <path_current_package> --poller
     $ resilient-sdk codegen -p <path_current_package> --gather-results
     $ resilient-sdk codegen -p <path_current_package> --gather-results '/usr/custom_app.log' -f 'func_one' 'func_two'"""
     CMD_DESCRIPTION = CMD_HELP
-    CMD_ADD_PARSERS = ["app_config_parser", "res_obj_parser", "io_parser"]
+    CMD_ADD_PARSERS = ["app_config_parser", "res_obj_parser", "io_parser", constants.SDK_SETTINGS_PARSER_NAME]
 
     def setup(self):
         # Define codegen usage and description
@@ -253,6 +255,47 @@ class CmdCodegen(BaseCmd):
             ps_dict[package_helpers.BASE_NAME_PAYLOAD_SAMPLES_EP_FAIL] = (u"{0}/blank.json.jinja2".format(package_helpers.PATH_TEMPLATE_PAYLOAD_SAMPLES), jinja_data)
         """
 
+    @staticmethod
+    def _check_and_create_md_files(package_mapping_dict, object_type, jinja_data):
+        """
+        Creates md files for workflows and playbooks using jinja2 templates.
+        
+        Note: as the mapping_dict is passed by reference,
+        there is no need to return it.
+        
+        :param package_mapping_dict: Dictionary of all the files to render
+        :type package_mapping_dict: dict
+        :param object_type: Type of object to create md files for (workflow or playbook)
+        :type object_type: str
+        :param jinja_data: A dictionary of the data to render the associated template with
+        :type jinja_data: dict
+        """
+        _obj_properties = MD_FILE_PROPERTIES[object_type]
+
+        # Get a list of workflow/playbooks names in export.
+        ob_names = [obj.get(_obj_properties["ResilientObj"]) for obj in jinja_data.get(object_type)]
+
+        for obj in jinja_data.get(object_type, []):
+            # Get workflow/playbooks name
+            ob_name = obj.get(_obj_properties["ResilientObj"])
+
+            # add sdk version to workflow data
+            obj["sdk_version"] = sdk_helpers.get_resilient_sdk_version()
+
+            # Generate pb_xx.md/wf_xx.md file name
+            # Don't add prefix if workflow/playbook name already begins with "wf_/pb_".
+            if re.search(_obj_properties["prefix_pattern"], ob_name):
+                file_name = u"{0}.md".format(ob_name)
+            else:
+                file_name = _obj_properties["obj_file_name"].format(ob_name)
+                # Check if file_name without extension already exists in workflow/playbooks names list.
+                if os.path.splitext(file_name)[0] in ob_names:
+                    raise SDKException(u"File name '{0}' already in use please recreate the {1} '{2}'."
+                        .format(file_name, object_type, ob_name))
+
+            # Add workflow/playbook to data directory
+            package_mapping_dict["data"][file_name] = (_obj_properties["jinja_file_path"], obj)
+
     @staticmethod
     def _gen_function(args):
         # TODO: Handle just generating a FunctionComponent for the /components directory
@@ -274,6 +317,16 @@ class CmdCodegen(BaseCmd):
         # The package_name will be specified in the args
         package_name = args.package
 
+        # Validate that the given path to the sdk settings is valid
+        try:
+            sdk_helpers.validate_file_paths(os.R_OK, args.settings)
+            # Parse the sdk_settings.json file
+            settings_file_contents = sdk_helpers.read_json_file(args.settings, "codegen")
+        except SDKException as err:
+            args.settings = None
+            settings_file_contents = {}
+            LOG.debug("Given path to SDK Settings is either not valid or not readable. Ignoring and using built-in values for codegen")
+
         # Get output_base, use args.output if defined, else current directory
         output_base = args.output if args.output else os.curdir
         output_base = os.path.abspath(output_base)
@@ -333,6 +386,24 @@ class CmdCodegen(BaseCmd):
         # add ::CHANGE_ME:: to jinja data
         jinja_data["change_me_str"] = constants.DOCGEN_PLACEHOLDER_STRING
 
+        # add license name, author, author_email, url
+        settings_file_contents_setup = settings_file_contents.get("setup", {})
+        jinja_data["license"] = settings_file_contents_setup.get("license", constants.CODEGEN_DEFAULT_SETUP_PY_LICENSE)
+        jinja_data["author"] = settings_file_contents_setup.get("author", constants.CODEGEN_DEFAULT_SETUP_PY_AUTHOR)
+        jinja_data["author_email"] = settings_file_contents_setup.get("author_email", constants.CODEGEN_DEFAULT_SETUP_PY_EMAIL)
+        jinja_data["url"] = settings_file_contents_setup.get("url", constants.CODEGEN_DEFAULT_SETUP_PY_URL)
+        jinja_data["long_description"] = settings_file_contents_setup.get("long_description", constants.CODEGEN_DEFAULT_SETUP_PY_LONG_DESC)
+
+        # add license_content to jinja_data and format in year if applicable
+        year = datetime.now().year
+        jinja_data["license_content"] = settings_file_contents.get("license_content", constants.CODEGEN_DEFAULT_LICENSE_CONTENT).format(year)
+        # add current SDK version to jinja data
+        jinja_data["sdk_version"] = sdk_helpers.get_resilient_sdk_version()
+        # add copyright info with year to jinja_data if present in settings_file
+        # and left-strip any leading "#" so that it fits well in the jinja template
+        copyright_str = str(settings_file_contents.get("copyright", constants.CODEGEN_DEFAULT_COPYRIGHT_CONTENT)).lstrip("#").format(year)
+        jinja_data["copyright"] = copyright_str
+
         # Validate we have write permissions
         sdk_helpers.validate_dir_paths(os.W_OK, output_base)
 
@@ -393,9 +464,9 @@ class CmdCodegen(BaseCmd):
                 # data isn't rendered with jinja — these are default jinja templates to be modified
                 # by the developer who is implementing a poller
                 "data": {
-                    "soar_create_case.jinja": package_helpers.PATH_DEFAULT_POLLER_CREATE_TEMPLATE,
-                    "soar_update_case.jinja": package_helpers.PATH_DEFAULT_POLLER_UPDATE_TEMPLATE,
-                    "soar_close_case.jinja": package_helpers.PATH_DEFAULT_POLLER_CLOSE_TEMPLATE
+                    package_helpers.BASE_NAME_POLLER_CREATE_CASE_TEMPLATE: package_helpers.PATH_DEFAULT_POLLER_CREATE_TEMPLATE,
+                    package_helpers.BASE_NAME_POLLER_UPDATE_CASE_TEMPLATE: package_helpers.PATH_DEFAULT_POLLER_UPDATE_TEMPLATE,
+                    package_helpers.BASE_NAME_POLLER_CLOSE_CASE_TEMPLATE: package_helpers.PATH_DEFAULT_POLLER_CLOSE_TEMPLATE
                 }
             }
             lib_mapping_dict = {
@@ -418,6 +489,10 @@ class CmdCodegen(BaseCmd):
             # Add package_name to function data
             f["package_name"] = package_name
 
+            # add sdk version to function data
+            f["sdk_version"] = sdk_helpers.get_resilient_sdk_version()
+            f["copyright"] = copyright_str
+
             # Get function name
             fn_name = f.get(ResilientObjMap.FUNCTIONS)
 
@@ -441,26 +516,11 @@ class CmdCodegen(BaseCmd):
             # Add a 'payload_samples/fn_name' directory and the files to it
             CmdCodegen.add_payload_samples(package_mapping_dict, fn_name, f)
 
-        # Get a list of workflow names in export.
-        wf_names = [w.get(ResilientObjMap.WORKFLOWS) for w in jinja_data.get("workflows")]
+        # checks and creates data for .md files for workflow
+        CmdCodegen._check_and_create_md_files(package_mapping_dict, "workflows", jinja_data)
 
-        for w in jinja_data.get("workflows"):
-            # Get workflow name
-            wf_name = w.get(ResilientObjMap.WORKFLOWS)
-
-            # Generate wf_xx.md file name
-            # Don't add prefix if workflow name already begins with "wf_".
-            if re.search(r"^wf_", wf_name):
-                file_name = u"{0}.md".format(wf_name)
-            else:
-                file_name = u"wf_{0}.md".format(wf_name)
-                # Check if file_name without extension already exists in workflow names list.
-                if os.path.splitext(file_name)[0] in wf_names:
-                    raise SDKException(u"File name '{0}' already in use please recreate the workflow '{1}'."
-                                       .format(file_name, wf_name))
-
-            # Add workflow to data directory
-            package_mapping_dict["data"][file_name] = ("data/workflow.md.jinja2", w)
+        # checks and creates .md files for playbooks
+        CmdCodegen._check_and_create_md_files(package_mapping_dict, "playbooks", jinja_data)
 
         newly_generated_files, skipped_files = CmdCodegen.render_jinja_mapping(
             jinja_mapping_dict=package_mapping_dict,
