@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# (c) Copyright IBM Corp. 2010, 2021. All Rights Reserved.
+# (c) Copyright IBM Corp. 2010, 2023. All Rights Reserved.
 
 import os
 
@@ -15,8 +15,10 @@ LOG_DIVIDER = "\n------------------------\n"
 ENV_VAR_DEV = "RES_SDK_DEV"
 ENV_VAR_APP_CONFIG_FILE = "APP_CONFIG_FILE"
 
-RESILIENT_LIBRARIES_VERSION = "47.1.0"
-RESILIENT_LIBRARIES_VERSION_DEV = "47.1.0"
+# UPDATE BEFORE RELEASING NEW VERSION
+RESILIENT_LIBRARIES_VERSION = "50.1.0"
+RESILIENT_LIBRARIES_VERSION_DEV = "50.1.0"
+
 RESILIENT_VERSION_WITH_PROXY_SUPPORT = (42, 0, 0)
 CURRENT_SOAR_SERVER_VERSION = None
 MIN_SOAR_SERVER_VERSION_PLAYBOOKS = 44.0
@@ -49,6 +51,8 @@ DOCGEN_TEMPLATE_PATH = os.path.join("data", "docgen", "templates")
 BASE_PATH_VALIDATE_DATA = os.path.join("data", "validate")
 VALIDATE_TEMPLATE_PATH = os.path.join(BASE_PATH_VALIDATE_DATA, "templates")
 VALIDATE_REPORT_TEMPLATE_NAME = "validate_report.md.jinja2"
+SETTINGS_TEMPLATE_PATH = os.path.join("data", "run_init")
+SETTINGS_TEMPLATE_NAME = "sdk_settings.json.jinja2"
 
 # docker test constants (used in validate)
 DOCKER_BASE_REPO = "registry.access.redhat.com/ubi8/python-39:latest"
@@ -72,11 +76,18 @@ URL_PYPI_VERSION = "https://pypi.org/pypi/resilient-sdk/json"
 # setup.py constants (for validate)
 SETUP_PY_INSTALL_REQ_NAME = "install_requires"
 
+# export.res constants (for validate)
+EXPORT_RES_SCRIPTS_ALLOWED_LANGUAGE_TYPES = ["python3"]
+EXPORT_RES_SUB_PLAYBOOK_PRE_PROCESSING_UNALLOWED_LANGUAGE = "\"pre_processing_script_language\":\"python\""
+EXPORT_RES_SUB_PLAYBOOK_OUTPUT_UNALLOWED_LANGUAGE = "\"script_language\":\"python\""
+EXPORT_RES_WORKFLOW_PRE_PROCESSING_UNALLOWED_LANGUAGE = "\"pre_processing_script_language\":\"python\""
+EXPORT_RES_WORKFLOW_POST_PROCESSING_UNALLOWED_LANGUAGE = "\"post_processing_script_language\":\"python\""
+
 # tox tests constants (used in validate)
 TOX_PACKAGE_NAME = "tox"
 TOX_INI_FILENAME = "tox.ini"
 TOX_TEMP_PATH_XML_REPORT = ".validate_tmp_dir"
-TOX_TESTS_DEFAULT_ARGS = ['--resilient_email', '"integrations@example.org"', '--resilient_password', '"supersecret"', '--resilient_host', '"example.com"', '--resilient_org', '"Test Organization"']
+TOX_TESTS_DEFAULT_ARGS = ['--resilient_email', 'integrations@example.org', '--resilient_password', 'supersecret', '--resilient_host', 'example.com', '--resilient_org', 'Test Organization', '-m', 'not livetest']
 TOX_MIN_ENV_VERSION = "py36" # the last character here must be a number and will be used as the base value for checks of envlist
 TOX_MIN_PACKAGE_VERSION = (3, 24, 4)
 
@@ -98,11 +109,47 @@ ICON_APP_LOGO_REQUIRED_HEIGHT = 72
 ICON_COMPANY_LOGO_REQUIRED_WIDTH = 100
 ICON_COMPANY_LOGO_REQUIRED_HEIGHT = 100
 
-# resilient-sdk codegen
-CODEGEN_JSON_SCHEMA_URI = "http://json-schema.org/draft-06/schema"
-
 # resilient-sdk docgen
 DOCGEN_PLACEHOLDER_STRING = "::CHANGE_ME::"
+SALT_HASH_MAP = {"0": ")","1": "!","2": "@","3": "#","4": "$","5": "%","6": "^","7": "&","8": "*","9": "("}
+DOCGEN_SALT_PREFIX = "docgen_{0}_salt"
+
+# resilient-sdk codegen
+CODEGEN_JSON_SCHEMA_URI = "http://json-schema.org/draft-06/schema"
+CODEGEN_DEFAULT_SETUP_PY_LICENSE = "<<insert here>>"
+CODEGEN_DEFAULT_SETUP_PY_AUTHOR = "<<your name here>>"
+CODEGEN_DEFAULT_SETUP_PY_EMAIL = "you@example.com"
+CODEGEN_DEFAULT_SETUP_PY_URL = "<<your company url>>"
+CODEGEN_DEFAULT_SETUP_PY_LONG_DESC = "<<{}>> Enter a long description, including the key features of the App. \\\\\\nMultiple continuation lines are supported with a backslash. Line breaks are supported too:\\n<br>- This will be rendered like a list\\n<br>- once the App is installed in SOAR".format(DOCGEN_PLACEHOLDER_STRING)
+CODEGEN_DEFAULT_LICENSE_CONTENT = "<<PUT YOUR LICENSE TEXT HERE>>"
+CODEGEN_DEFAULT_COPYRIGHT_CONTENT = "<<PUT YOUR COPYRIGHT TEXT HERE>>"
+
+# resilient-sdk init internal defaults
+INIT_INTERNAL_AUTHOR = "IBM SOAR"
+INIT_INTERNAL_AUTHOR_EMAIL = ""
+INIT_INTERNAL_URL = "https://ibm.com/mysupport"
+INIT_INTERNAL_LICENSE = "MIT"
+INIT_INTERNAL_LONG_DESC = "Links: \
+<ul><a target='blank' href='https://ibm.com/mysupport'>Support</a></ul>\
+<ul><a target='blank' href='https://ideas.ibm.com/'>Enhancement Requests</a></ul>"
+INIT_INTERNAL_LICENSE_CONTENT = u"Copyright © IBM Corporation {0}\\n\\n\
+Permission is hereby granted, free of charge, to any person obtaining a copy\\n\
+of this software and associated documentation files (the \\\"Software\\\"), to\\n\
+deal in the Software without restriction, including without limitation the\\n\
+rights to use, copy, modify, merge, publish, distribute, sublicense, and/or\\n\
+sell copies of the Software, and to permit persons to whom the Software is\\n\
+furnished to do so, subject to the following conditions: \\n\\n\
+The above copyright notice and this permission notice shall be included in\\n\
+all copies or substantial portions of the Software. \\n\\n\
+THE SOFTWARE IS PROVIDED \\\"AS IS\\\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\\n\
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\\n\
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\\n\
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\\n\
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING\\n\
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS\\n\
+IN THE SOFTWARE."
+INIT_INTERNAL_COPYRIGHT = u"(c) Copyright IBM Corp. 2010, {0}. All Rights Reserved."
+
 
 # resilient-sdk validate
 VALIDATE_LOG_LEVEL_CRITICAL = "CRITICAL"
