@@ -22,25 +22,29 @@ import tempfile
 import time
 import uuid
 import xml.etree.ElementTree as ET
+from argparse import SUPPRESS
+from collections import OrderedDict
 from zipfile import BadZipfile, ZipFile, is_zipfile
 
 import pkg_resources
 import requests
 import requests.exceptions
 from jinja2 import Environment, PackageLoader
-from resilient import ArgumentParser
-from resilient import constants as res_constants
-from resilient import get_client, get_config_file
-from resilient.helpers import remove_tag
 from resilient_sdk.util import constants
 from resilient_sdk.util.jinja2_filters import add_filters_to_jinja_env
 from resilient_sdk.util.resilient_objects import (DEFAULT_INCIDENT_FIELD,
                                                   DEFAULT_INCIDENT_TYPE,
+                                                  SCRIPT_TYPE_MAP,
                                                   ResilientFieldTypes,
                                                   ResilientObjMap,
                                                   ResilientTypeIds)
 from resilient_sdk.util.sdk_exception import SDKException
 
+from resilient import ArgumentParser
+from resilient import constants as res_constants
+from resilient import get_client, get_config_file
+from resilient.helpers import remove_tag
+
 if sys.version_info.major < 3:
     # Handle PY 2 specific imports
     # JSONDecodeError is not available in PY2.7 so we set it to None
@@ -160,13 +164,15 @@ def read_file(path):
     return file_lines
 
 
-def read_json_file(path):
+def read_json_file(path, section=None):
     """
     If the contents of the file at path is valid JSON,
     returns the contents of the file as a dictionary
 
     :param path: Path to JSON file to read
     :type path: str
+    :param section: Section name in JSON file (eg. commands in resilient-sdk)
+    :type section: str
     :return: File contents as a dictionary
     :rtype: dict
     """
@@ -178,7 +184,14 @@ def read_json_file(path):
         # a JSONDecodeError if it cannot load the JSON from the file
         except (ValueError, JSONDecodeError) as err:
             raise SDKException("Could not read corrupt JSON file at {0}\n{1}".format(path, err))
-    return file_contents
+    if section:
+        if section in file_contents:
+            return file_contents.get(section, {})
+        else: 
+            LOG.debug("Section {} not found in provided JSON.".format(section))
+            return {}
+    else:
+        return file_contents
 
 
 def read_zip_file(path, pattern):
@@ -543,6 +556,32 @@ def get_object_api_names(api_name, list_objs):
         return []
 
 
+def get_script_info(each_script_in_playbook, scripts_in_location, script_type):
+    '''
+    Extracts script related information for playbooks. Scripts can be of 2 types: local or global.
+    Local scripts live within the playbook itself, while global scripts are stored in the global_export dict.
+    
+    Note: The scripts are passed by reference. They need not be returned. They are directly updated.
+    :param each_script_in_playbook: Individual scripts found in the playbook
+    :type each_script_in_playbook: dict
+    :param scripts_in_location: All scripts in the location (global or local). Global scripts are pulled directly from the global_export dict. Local scripts are pulled from the playbook
+    :type scripts_in_location: list
+    :param script_type: The type of script (global or local)
+    :type script_type: str
+    '''
+    found_script = False
+    for sc in scripts_in_location:
+        if each_script_in_playbook.get("uuid", "uuid_not_found_pb") == sc.get("uuid", "uuid_not_found_sc"):
+            each_script_in_playbook["name"] = sc.get("name")
+            each_script_in_playbook["script_type"] = script_type
+            each_script_in_playbook["description"] = sc.get("description")
+            each_script_in_playbook["object_type"] = sc.get("object_type")
+            each_script_in_playbook["script_text"] = sc.get("script_text", "")
+            found_script = True
+            break
+    return found_script
+
+
 def get_obj_from_list(identifer, obj_list, condition=lambda o: True):
     """
     Return a dict the name of the object as its Key
@@ -788,6 +827,60 @@ def get_from_export(export,
     else:
         return_dict["playbooks"] = get_res_obj("playbooks", ResilientObjMap.PLAYBOOKS, "Playbook", playbooks, export)
 
+        if get_related_objects:
+            # For Playbooks we attempt to locate related functions and scripts
+            # Get Functions in Playbooks
+            for playbook in return_dict.get("playbooks", []):
+                # This gets all the functions and scripts in the Playbooks's XML
+                pb_objects = get_playbook_objects(playbook)
+
+                # Add the Display Name and Name to each wf_function
+                for pb_fn in pb_objects.get("functions", []):
+                    for fn in return_dict["functions"]:
+                        if pb_fn.get("uuid", "uuid_not_found_pb") == fn.get("uuid", "uuid_not_found_fn"):
+                            pb_fn["name"] = fn.get("name")
+                            pb_fn["display_name"] = fn.get("display_name")
+                            pb_fn["message_destination"] = fn.get("destination_handle", "")
+                            break
+
+                # If a playbook script is local, its information can be directly extracted from the playbook,
+                # if not, the script's information has to be extracted from the global scripts
+                for pb_sc in pb_objects.get("scripts", []):
+                    # If the script is a local script, then we need to find the script in the Playbook
+                    found_script = get_script_info(pb_sc, playbook.get("local_scripts"), SCRIPT_TYPE_MAP.get("local"))
+
+                    # If script not found in playbook, searching Global Scripts
+                    found_script = get_script_info(pb_sc, return_dict["scripts"], SCRIPT_TYPE_MAP.get("global")) if not found_script else True
+
+                    # If the script is not found in the Playbook or Global Scripts, then its UUID is used to find the script form the org export
+                    if not found_script:
+                        _unfound_scripts = get_res_obj("scripts", "uuid", "Script", [pb_sc.get("uuid")], export)
+                        for script in _unfound_scripts:
+                            # Renaming the x_api_name to name. Since the script was fetched with UUID, the x_api_name is the UUID
+                            script["x_api_name"] = script["name"]
+                        found_script = get_script_info(pb_sc, _unfound_scripts, SCRIPT_TYPE_MAP.get("global"))
+                        # Adding script to return_dict. This is to make sure that its included in the export.res and customize.py
+                        return_dict["scripts"].extend(_unfound_scripts)
+
+                # add name to each sub playbook input
+                for pb_sub_pb in pb_objects.get("sub_pbs", []):
+                    replace_uuids_in_subplaybook_data(pb_sub_pb, export)
+
+                activation_type = playbook.get("activation_type", "")
+                if playbook.get("type") == "subplaybook":
+                    playbook["activation_type"] = "Sub-playbook"
+                else:
+                    playbook["activation_type"] = activation_type.capitalize()
+
+                if activation_type.lower() == "manual":
+                    activation_conditions = playbook.get("manual_settings", {}).get("activation_conditions", {})
+                else:
+                    activation_conditions = playbook.get("activation_details", {}).get("activation_conditions", {})
+                playbook["conditions"] = str_repr_activation_conditions(activation_conditions) or "-"
+                playbook["pb_functions"] = pb_objects.get("functions")
+                playbook["pb_scripts"]   = pb_objects.get("scripts")
+                playbook["pb_sub_pbs"]   = pb_objects.get("sub_pbs")
+
     return return_dict
 
 
@@ -1152,6 +1245,126 @@ def get_workflow_functions(workflow, function_uuid=None):
     return return_functions
 
 
+def get_playbook_objects(playbook, function_uuid=None):
+    """Parses the XML of the Playbook Object and returns
+    a List of all Functions and Scripts found. The scripts
+    returned only has the uuid attribute. This can later
+    be used to extract all script-related information either
+    form the playbook export or from global scripts. If
+    function_uuid is defined returns all occurrences of that
+    function only.
+
+    Function Attributes:
+    - uuid: String
+    - inputs: Dict
+    - pre_processing_script: String
+    - result_name: String
+
+    Script Attributes:
+    - uuid: String
+    """
+    playbook_elements = {"functions": [], "scripts": [], "sub_pbs": []}
+
+    # Playbook XML text
+    pb_xml = playbook.get("content", {}).get("xml", None)
+
+    if pb_xml is None:
+        raise SDKException("Could not load xml content from Playbooks: {0}".format(playbook))
+
+    # Get the root element + encoded in utf8 in order to handle Unicode
+    root = ET.fromstring(pb_xml.encode("utf8"))
+
+    # Get the prefix for each element's tag
+    tag_prefix = root.tag.replace("definitions", "")
+
+    xml_function_path = "./{0}process/{0}serviceTask/{0}extensionElements/*".format(tag_prefix)
+    xml_script_path = "./{0}process/{0}scriptTask/{0}extensionElements/*".format(tag_prefix)
+    xml_sub_playbook_path = "./{0}process/{0}callActivity/{0}extensionElements/*".format(tag_prefix)
+
+    if function_uuid is not None:
+        xml_function_path = "{0}[@uuid='{1}']".format(xml_function_path, function_uuid)
+
+        # Get all elements at xml_path that have the uuid of the function
+        playbook_elements += root.findall(xml_function_path)
+    else:
+        # Paths to functions, scripts, and subplaybooks in the XML
+        the_extension_elements  = root.findall(xml_function_path)
+        the_extension_elements += root.findall(xml_script_path)
+        the_extension_elements += root.findall(xml_sub_playbook_path)
+
+        for extension_element in the_extension_elements:
+            return_function = {}
+            # Extracting Function related data from the XML
+            if "function" in extension_element.tag:
+                return_function = json.loads(extension_element.text)
+                return_function["uuid"] = extension_element.attrib.get("uuid", "")
+                return_function["result_name"] = return_function.get("result_name", None)
+                return_function["pre_processing_script"] = return_function.get("pre_processing_script", None)
+                playbook_elements["functions"].append(return_function)
+
+            # Extracting Script related data from the XML
+            if "script" in extension_element.tag:
+                return_function["uuid"] = extension_element.get("uuid", "")
+                playbook_elements["scripts"].append(return_function)
+
+            # Extracting Subplaybook related data from the XML
+            if "sub-playbook" in extension_element.tag:
+                sub_pb = json.loads(extension_element.text)
+                sub_pb["uuid"] = extension_element.attrib.get("uuid", "")
+                playbook_elements["sub_pbs"].append(sub_pb)
+
+    return playbook_elements
+
+
+def replace_uuids_in_subplaybook_data(playbook_data, export):
+    """
+    When processing a subplaybook within a playbook, it is possible that there are
+    references to objects only through UUIDs. Those are not useful for
+    generating Markdown files where a user wants to read through in plain text
+    the values of the objects referenced. This function replaces any relevant
+    UUIDs with their true value from the export. The replacement is in place
+
+    :param playbook_data: sub playbook to process
+    :type playbook_data: dict
+    :param export: full export data
+    :type export: dict
+    """
+
+    # add name to each sub playbook input
+    for sub_pb in export.get("playbooks", []):
+        if playbook_data.get("uuid", "uuid_not_found_pb") == sub_pb.get("uuid", "uuid_not_found_fn"):
+            fields = sub_pb.get("fields_type", {}).get("fields", {})
+
+            # update sub playbook's name
+            playbook_data["name"] = sub_pb.get("display_name")
+            for field_name, field in fields.items():
+                if field.get("uuid", "uuid_not_found") in playbook_data.get("inputs", {}):
+                    # convert input uuid to input_name
+                    playbook_data["inputs"][field.get("uuid")]["input_name"] = field.get("text")
+                    playbook_data["inputs"][field.get("uuid")]["input_api_name"] = field_name
+                    # add input type
+                    playbook_data["inputs"][field.get("uuid")]["input_type_name"] = field.get("input_type")
+                    # selects and multiselects reference their UUID in the data extracted from xml,
+                    # so we need to replace that with the true value found in the sub_pb
+                    if field.get("input_type") == "select":
+                        select_input_uuid = playbook_data["inputs"][field.get("uuid")]["static_input"]["select_value"]
+                        playbook_data["inputs"][field.get("uuid")]["static_input"]["select_value"] = next(value.get("label") for value in field.get("values") if value.get("uuid") == select_input_uuid)
+                    elif field.get("input_type") == "multiselect":
+                        select_input_uuids = playbook_data["inputs"][field.get("uuid")]["static_input"]["multiselect_value"]
+                        playbook_data["inputs"][field.get("uuid")]["static_input"]["multiselect_value"] = ", ".join(value.get("label") for value in field.get("values") if value.get("uuid") in select_input_uuids)
+
+    # make input easier to get in jinja2
+    for _, input in playbook_data.get("inputs", {}).items():
+        input_str_repr = ""
+        if "expression_input" in input:
+            input_str_repr = input.get("expression_input", {}).get("expression", "UNKNOWN")
+        elif "static_input" in input:
+            in_content = input.get("static_input")
+            # there's only one item ever in in_content so we can use ``next()``
+            # on the generator below to get the item's value
+            input_str_repr = next(value for _, value in in_content.items())
+        input["input_as_str"] = input_str_repr
+
 def get_main_cmd():
     """
     Return the "main" command from the command line.
@@ -1412,6 +1625,10 @@ def parse_optionals(optionals):
 
     for option in optionals:
 
+        # skipped any suppressed options
+        if option.help == SUPPRESS:
+            continue
+
         option_strings = ", ".join(option.option_strings)
 
         tabs = "\t\t\t"
@@ -1528,7 +1745,7 @@ def scrape_results_from_log_file(path_log_file):
     regex_fn_name = re.compile(r'\[([\w]+)\] Result\:')  # Getting <fn_name> from [<fn_name>] Result: {'version': 2.0, 'success': True...
 
     for l in reversed(log_file_contents):
-        match = regex_line.search(l, endpos=120)
+        match = regex_line.search(l)
 
         if match:
             fn_name_group_index = 0
@@ -1567,13 +1784,80 @@ def handle_file_not_found_error(e, msg):
     else:
         raise e
 
+def str_repr_activation_conditions(activation_conditions):
+    """
+    Represent "activation conditions" as a string.
+
+    Example:
+        activation_conditions = {
+            "conditions": [
+                {
+                    "evaluation_id": None,
+                    "field_name": "incident.id",
+                    "method": "not_equals",
+                    "type": None,
+                    "value": 123456
+                }
+            ],
+            "logic_type": "all"
+        }
+    
+
+    :param activation_conditions: _description_
+    :type activation_conditions: _type_
+    """
+    conditions = OrderedDict()
+    for i, condition in enumerate(activation_conditions.get("conditions", []), start=1):
+        field_name = condition.get("field_name") or ""
+        method = condition.get("method") or ""
+        value = condition.get("value") or ""
+
+        # index into the dictionary by the evaluation ID which is only present
+        # if the logic_type is "advanced". If not present (i.e. logic_type==any or all),
+        # then we just keep track with the index in which it was found in the list
+        # NOTE: use ``filter(None, [...items...])`` here to drop any elements that might
+        # be None. This would occur in the case that a condition doesn't have
+        # all three elements. Example: "incident_created" doesn't have any method or value
+        conditions[condition.get("evaluation_id") or i] = u" ".join(filter(None, [str(field_name), str(method), str(value)]))
+
+    if str(activation_conditions.get("logic_type", "")).lower() == "all":
+        return u" AND ".join(conditions.values())
+    elif str(activation_conditions.get("logic_type", "")).lower() == "any":
+        return u" OR ".join(conditions.values())
+    else:
+        condition_str = activation_conditions.get("custom_condition")
+        # here we do two passes to perform a kind of "salting"
+        # this is necessary to avoid the condition where in one iteration
+        # we replace "1" with "1234" and on the next iteration we replace
+        # "2" with something else; in this kind of scenario, we'd be
+        # replacing a "2" which we didn't want to
+        # So instead, we generate a unique salt and 
+        # we replace the original number with that. then on the second pass,
+        # we replace the salt with the intended value
+        # It is also CRUCIAL that the keys are processed in reverse order
+        # to properly handle double digit evaluation IDs
+        salts = {}
+        for evaluation_id in sorted(conditions.keys(), reverse=True):
+            # numbers here are the enemy -- so first we need to map each individual digit to
+            # a special string value (I decided to use the corresponding values on the keyboard)
+            hashed_eval_id = "".join(constants.SALT_HASH_MAP[id] for id in str(evaluation_id))
+            # then add our unique "docgen_{}_salt" prefix to add extra uniqueness
+            # NOTE: uniqueness is not guaranteed here from other possible values
+            # which we'll be substituting in, but it is unlikely that anyone has
+            # "docgen_!@#$_salt" in their system... so uniqueness is practically guaranteed
+            salts[evaluation_id] = constants.DOCGEN_SALT_PREFIX.format(hashed_eval_id)
+            condition_str = condition_str.replace(str(evaluation_id), salts.get(evaluation_id))
+        for evaluation_id in conditions:
+            condition_str = condition_str.replace(salts.get(evaluation_id), conditions.get(evaluation_id))
+        return condition_str
+
 class ContextMangerForTemporaryDirectory():
     """
     This is a small class for safe use of ``tempfile.mkdtemp()`` which requires cleanup after
     use. The class effectively is the same as ``tempfile.TemporaryDirectory``, however, 
     that class isn't available before python 3 thus the implementation here.
     On enter, ``tempfile.mkdtemp(*args, **kwargs)`` is called and on exit ``shutil.rmtree(path_to_dir)`` is called.
-    
+
     Example:
 
     .. code-block:: python
@@ -1586,7 +1870,7 @@ class ContextMangerForTemporaryDirectory():
             # ...
 
         # on exit of context manager, path_to_tmp_dir will be cleaned up by implicit call of the ``__exit__`` method
-    
+
     :param args: any ordered args that are relevant to calling ``tempfile.mkdtemp()``
     :param kwargs: any keyword arguments relevant to calling ``tempfile.mkdtemp()``
     """
